==> masamune_core-0.1.1.tar.gz: lib/dartcore/utility/texts.dart <==
part of masamune.dartcore;

/// Text-related utility classes
class Texts {
  static const String _domain = "mathru.net";
  static const String _passwordChars = "23456789abcdefghjkmnpqrstuvwxyABCDEFGHJKLMNPQRSTUVWXYZ";
  static const String _passwordCharsForID = "23456789abcdefghjkmnpqrstuvwxy";
  /// Get UUID.
  /// A 32-byte string without hyphens is output
  static String get uuid {
    Uuid uuid = Uuid();
    return uuid.v5(Uuid.NAMESPACE_URL, _domain).replaceAll( "-", Const.empty);
  }
  /// Create a code of length [length] randomly.
  /// [seed] can be specified.
  /// 
  /// [length]: Cord length
  /// [seed]: Seed number
  static String code( int length, {int seed = 0} ){
    int _length = _passwordChars.length;
    Random rand = seed != 0 ? Random(seed) : Random();
    List<int> codeUnits = List.generate(
      length, 
      (index) {
        final n = rand.nextInt(_length);
        return _passwordChars.codeUnitAt(n);
      },
    );
    return new String.fromCharCodes(codeUnits);
  }
  /// Create a code of length [length] randomly for id.
  /// Characters that are difficult to understand are omitted
  /// [seed] can be specified.
  /// 
  /// [length]: Cord length
  /// [seed]: Seed number
  static String id( int length, {int seed = 0} ){
    int _length = _passwordCharsForID.length;
    Random rand = seed != 0 ? Random(seed) : Random();
    List<int> codeUnits = List.generate(
      length, 
      (index) {
        final n = rand.nextInt(_length);
        return _passwordCharsForID.codeUnitAt(n);
      },
    );
    return new String.fromCharCodes(codeUnits);
  }
  /// Formats and displays text.
  /// Same type as PHP
  static String format( String format, [List args] ) => sprintf( format, args );
}

==> masamune_core-0.2.0.tar.gz: lib/dartcore/utility/texts.dart <==
part of masamune.dartcore;

/// Text-related utility classes.
class Texts {
  static const String _passwordChars = "23456789abcdefghjkmnpqrstuvwxyABCDEFGHJKLMNPQRSTUVWXYZ";
  static const String _passwordCharsForID = "23456789abcdefghjkmnpqrstuvwxy";
  /// Get UUID.
  /// 
  /// A 32-byte string without hyphens is output.
  static String get uuid {
    Uuid uuid = Uuid();
    return uuid.v4().replaceAll( "-", Const.empty);
  }
  /// Create a code of length [length] randomly.
  /// 
  /// [seed] can be specified.
  /// 
  /// [length]: Cord length.
  /// [seed]: Seed number.
  static String code( int length, {int seed = 0} ){
    int _length = _passwordChars.length;
    Random rand = seed != 0 ? Random(seed) : Random();
    List<int> codeUnits = List.generate(
      length, 
      (index) {
        final n = rand.nextInt(_length);
        return _passwordChars.codeUnitAt(n);
      },
    );
    return new String.fromCharCodes(codeUnits);
  }
  /// Create a code of length [length] randomly for id.
  /// 
  /// Characters that are difficult to understand are omitted.
  /// 
  /// [seed] can be specified.
  /// 
  /// [length]: Cord length.
  /// [seed]: Seed number.
  static String id( int length, {int seed = 0} ){
    int _length = _passwordCharsForID.length;
    Random rand = seed != 0 ? Random(seed) : Random();
    List<int> codeUnits = List.generate(
      length, 
      (index) {
        final n = rand.nextInt(_length);
        return _passwordCharsForID.codeUnitAt(n);
      },
    );
    return new String.fromCharCodes(codeUnits);
  }
  /// Formats and displays text.
  /// 
  /// Same type as PHP.
  static String format( String format, [List args] ) => sprintf( format, args );
}
